src/Configuration.h
branchv_0
changeset 33 e87c231afb77
parent 26 421608ecc12a
--- a/src/Configuration.h	Sat Jun 06 01:50:45 2020 +0200
+++ b/src/Configuration.h	Fri Sep 25 01:59:16 2020 +0200
@@ -24,7 +24,7 @@
 
 namespace relpipe {
 namespace tr {
-namespace guile {
+namespace scheme {
 
 class DefinitionRecipe {
 public:
@@ -44,19 +44,19 @@
 	}
 
 	relpipe::writer::string_t relation;
-	relpipe::writer::string_t guileBeforeRecords;
-	relpipe::writer::string_t guileAfterRecords;
-	relpipe::writer::string_t guileForEach;
-	relpipe::writer::string_t guileWhere;
-	relpipe::writer::string_t guileHasMoreRecords;
+	relpipe::writer::string_t schemeBeforeRecords;
+	relpipe::writer::string_t schemeAfterRecords;
+	relpipe::writer::string_t schemeForEach;
+	relpipe::writer::string_t schemeWhere;
+	relpipe::writer::string_t schemeHasMoreRecords;
 	
 	/**
-	 * If true, additional relation will be generated: mapping between relpipe attribute names and Guile variable names
+	 * If true, additional relation will be generated: mapping between relpipe attribute names and Scheme variable names
 	 */
 	bool debugVariableMapping = false;
 
 	/**
-	 * If true, Guile code will be executed, but no output will be generated.
+	 * If true, Scheme code will be executed, but no output will be generated.
 	 */
 	bool drop = false;
 
@@ -94,9 +94,9 @@
 	 */
 	std::vector<DefinitionRecipe> definitions;
 
 	// TODO: --create t2 3 a integer b boolean '…guile…' – allow creating new relations? Or allow calling startRelation() and attribute() from Guile?
 	// TODO: --has-more-relations '…guile…' – called after all relations … ?
 	// TODO: --dynamic-output-attributes '…guile…' – used instead or together with --output-attribute
 
 	virtual ~Configuration() {
 	}
@@ -94,9 +94,9 @@
 	std::vector<DefinitionRecipe> definitions;
 
-	// TODO: --create t2 3 a integer b boolean '…guile…' – allow creating new relations? Or allow calling startRelation() and attribute() from Guile?
-	// TODO: --has-more-relations '…guile…' – called after all relations … ?
-	// TODO: --dynamic-output-attributes '…guile…' – used instead or together with --output-attribute
+	// TODO: --create t2 3 a integer b boolean '…scheme…' – allow creating new relations? Or allow calling startRelation() and attribute() from Scheme?
+	// TODO: --has-more-relations '…scheme…' – called after all relations … ?
+	// TODO: --dynamic-output-attributes '…scheme…' – used instead or together with --output-attribute
 
 	virtual ~Configuration() {